ASSERT_KEY = "assert"
BODY_KEY = "body"
ENDPOINTS_KEY = "endpoints"
HEADERS_KEY = "headers"
METHOD_KEY = "method"
NAME_KEY = "name"
PARAMS_KEY = "params"
PATH_KEY = "path"
REQUESTS_KEY = "requests"
ROOT_SCOPE = "root"
TESTS_KEY = "tests"
VARS_KEY = "vars"
DELAY_KEY = "delay"
RETRY_KEY = "retry"
MAX_RETRIES_KEY = "max_retries"
